.. moduleauthor:: Paul Ross <apaulross@gmail.com>
.. sectionauthor:: Paul Ross <apaulross@gmail.com>

.. Description of the file formats that TotalDepth understands.

Petrophysical File Formats that TotalDepth can Process
=========================================================

.. toctree::
   :maxdepth: 2

TotalDepth is currently at **Alpha**, release version 0.1.0.

=================  =======  ========  ============================================================================
Format             Support  Since     Notes.
=================  =======  ========  ============================================================================
LIS79              Full     0.1.0     
LIS-A              Partial  0.1.0     No direct XNAM support.
LAS version 1.2    Full     0.1.0     
LAS version 2.0    Full     0.1.0     
LAS version 3.0    None
WellLogML          None               Absence of good test cases.
                                      The format seems to have made little impact on the industry.
RP66v1 "DLIS"      Proto.             Absence of good test cases.
RP66v2 "DLIS"      Proto.             Absence of good test cases.
SEG-Y etc.         None               Use cases?
Positioning        None               Fairly simple, use cases?
=================  =======  ========  ============================================================================
